@@ -1,3 +1,4 @@
+/// The plotting context and more stuff
 use std::borrow::Borrow;
 use std::fmt::Debug;
 /// The abstraction of a chart
@@ -7,7 +8,7 @@ use std::ops::Range;
 use crate::drawing::backend::DrawingBackend;
 use crate::drawing::coord::{CoordTranslate, MeshLine, Ranged, RangedCoord, Shift};
 use crate::drawing::{DrawingArea, DrawingAreaErrorKind};
-use crate::element::{Drawable, PointCollection};
+use crate::element::{Drawable, PointCollection, Rectangle};
 use crate::style::{FontDesc, Mixable, RGBColor, ShapeStyle, TextStyle};
 
 /// The helper object to create a chart
@@ -51,14 +52,18 @@ impl<'a, DB: DrawingBackend> ChartBuilder<'a, DB> {
     }
 
     /// Set the caption of the chart
-    pub fn caption<S: AsRef<str>>(&mut self, caption: S, style: TextStyle) -> &mut Self {
+    pub fn caption<'b, S: AsRef<str>, Style: Into<TextStyle<'b>>>(
+        &mut self,
+        caption: S,
+        style: Style,
+    ) -> &mut Self {
         if self.titled_area.is_some() {
             return self;
         }
 
         self.titled_area = Some(
             self.root_area
-                .titled(caption.as_ref(), style)
+                .titled(caption.as_ref(), style.into())
                 .expect("Unable to create caption for chart"),
         );
         return self;
@@ -103,6 +108,7 @@ impl<'a, DB: DrawingBackend> ChartBuilder<'a, DB> {
         return ChartContext {
             x_label_area,
             y_label_area,
+            series_area: None,
             drawing_area: drawing_area.apply_coord_spec(RangedCoord::new(
                 x_spec.into(),
                 y_spec.into(),
@@ -114,9 +120,10 @@ impl<'a, DB: DrawingBackend> ChartBuilder<'a, DB> {
 
 /// The context of the chart
 pub struct ChartContext<DB: DrawingBackend, CT: CoordTranslate> {
-    pub x_label_area: Option<DrawingArea<DB, Shift>>,
-    pub y_label_area: Option<DrawingArea<DB, Shift>>,
-    pub drawing_area: DrawingArea<DB, CT>,
+    x_label_area: Option<DrawingArea<DB, Shift>>,
+    y_label_area: Option<DrawingArea<DB, Shift>>,
+    series_area: Option<DrawingArea<DB, Shift>>,
+    drawing_area: DrawingArea<DB, CT>,
 }
 
 pub struct MeshStyle<'a, X: Ranged, Y: Ranged, DB>
@@ -165,13 +172,19 @@ where
         return self;
     }
 
-    pub fn x_label_formatter(&mut self, fmt: Box<Fn(&X::ValueType) -> String>) -> &mut Self {
-        self.format_x = fmt;
+    pub fn x_label_formatter(
+        &mut self,
+        fmt: &'static dyn Fn(&X::ValueType) -> String,
+    ) -> &mut Self {
+        self.format_x = Box::new(fmt);
         return self;
     }
 
-    pub fn y_label_formatter(&mut self, fmt: Box<dyn Fn(&Y::ValueType) -> String>) -> &mut Self {
-        self.format_y = fmt;
+    pub fn y_label_formatter(
+        &mut self,
+        fmt: &'static dyn Fn(&Y::ValueType) -> String,
+    ) -> &mut Self {
+        self.format_y = Box::new(fmt);
         return self;
     }
 
@@ -180,7 +193,7 @@ where
         std::mem::swap(&mut target, &mut self.target);
         let target = target.unwrap();
 
-        let default_font = FontDesc::new("ArialMT", 10.0);
+        let default_font = FontDesc::new("DejaVu Serif", 10.0);
         let default_color = RGBColor(0, 0, 0);
         let default_label_style = TextStyle {
             font: &default_font,
@@ -192,6 +205,7 @@ where
         let default_mesh_color_1 = RGBColor(0, 0, 0).mix(0.4);
         let default_mesh_style_1 = ShapeStyle {
             color: &default_mesh_color_1,
+            filled: false,
         };
         let mesh_style_1 =
             unsafe { std::mem::transmute::<_, Option<&ShapeStyle>>(self.line_style_1) }
@@ -200,6 +214,7 @@ where
         let default_mesh_color_2 = RGBColor(0, 0, 0).mix(0.2);
         let default_mesh_style_2 = ShapeStyle {
             color: &default_mesh_color_2,
+            filled: false,
         };
         let mesh_style_2 =
             unsafe { std::mem::transmute::<_, Option<&ShapeStyle>>(self.line_style_2) }
@@ -258,6 +273,18 @@ impl<DB: DrawingBackend, X: Ranged, Y: Ranged> ChartContext<DB, RangedCoord<X, Y
         return self.drawing_area.get_y_range();
     }
 
+    /// Defines a series label area
+    pub fn define_series_label_area<'a, S: Into<ShapeStyle<'a>>>(
+        &mut self,
+        pos: (u32, u32),
+        size: (u32, u32),
+        bg_style: S,
+    ) -> Result<(), DrawingAreaErrorKind<DB::ErrorType>> {
+        self.series_area = Some(self.drawing_area.strip_coord_spec().shrink(pos, size));
+        let element = Rectangle::new([(0, 0), (size.0 as i32, size.1 as i32)], bg_style.into());
+        return self.series_area.as_ref().unwrap().draw(&element);
+    }
+
     /// Draw a series
     pub fn draw_series<E, R, S>(&self, series: S) -> Result<(), DrawingAreaErrorKind<DB::ErrorType>>
     where
