@@ -2,7 +2,16 @@
 use crate::drawing::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
 use std::borrow::Borrow;
 
-/// The trait that represents an element drawed on the canvas
+mod basic_shapes;
+pub use basic_shapes::*;
+
+mod points;
+pub use points::*;
+
+mod composable;
+pub use composable::{ComposedElement, EmptyElement};
+
+/// The trait indicates it's a collection of points
 pub trait PointCollection<'a, Coord> {
     /// The item in point iterator
     type Borrow: Borrow<Coord>;
@@ -14,6 +23,7 @@ pub trait PointCollection<'a, Coord> {
     fn point_iter(self) -> Self::IntoIter;
 }
 
+/// The trait indicates we are able to draw it on a drawing area
 pub trait Drawable {
     /// Actually draws the element. The key points is already translated into the
     /// image cooridnate and can be used by DC directly
@@ -23,9 +33,3 @@ pub trait Drawable {
         backend: &mut DB,
     ) -> Result<(), DrawingErrorKind<DB::ErrorType>>;
 }
-
-mod basic_shapes;
-pub use basic_shapes::*;
-
-mod points;
-pub use points::*;
